Instrument Response Function
============================

Instrument response function (IRF) usually modeled to gaussian, cauchy and pseudo voigt shape.

.. toctree::
   :maxdepth: 4

   math.signal_model.irf.cauchy
   math.signal_model.irf.gaussian
   math.signal_model.irf.pseudo_voigt
